# opendatahub-tests

This repository contains ODH / Red Hat Openshift AI (RHOAI) tests.  
The tests are written in Python and use [pytest](https://docs.pytest.org/en/stable/) as a test framework.


## Getting started
Please follow the [Getting Started Guide](docs/GETTING_STARTED.md) on how to run the tests.


## Contribute to opendatahub-tests
Please follow the [Contributing Guide](docs/CONTRIBUTING.md) and the [Developer guide](docs/DEVELOPER_GUIDE.md)


## GitHub workflows
Please follow the [GitHub workflows Guide](docs/GITHUB_WORKFLOWS.md) for more information.
